@@ -138,11 +138,10 @@ void getEdgeSimilarities_all(int *ea, int *eb, int *numedg, int *numnodes, int *
 
 	{
 
-	int i, j, k = 0, finda, findab, findb, findba, add, which, perc = 0;
+	int i, j, k = 0;
 	int first = -1, last = -1, sum = 0, runn = 0;
 	double dotprod, absA, absB, numerat, denom, distm;
 	float prog;
-	bool end = FALSE;
 	vector<double> row;
 	vector<double> temp;
 	vector<int> edgeA;
